/*
 * Copyright (C) 2014, 2016 Karl Wette
 * Copyright (C) 2009-2013 Adam Mercer
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*
 * LALInspiralVCSInfo.h - LALInspiral VCS Information Header
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALINSPIRALVCSINFOHEADER_H
#define _LALINSPIRALVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <lal/LALInspiralVCSInfo.h>
#include <lal/LALInspiralConfig.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information */
#define LALINSPIRAL_VCS_ID "a00b854511244fc757da2d6f5a689699236e1327"
#define LALINSPIRAL_VCS_DATE "2017-02-6 18:16:01 +0000"
#define LALINSPIRAL_VCS_BRANCH "None"
#define LALINSPIRAL_VCS_TAG "lalinspiral-v1.7.7"
#define LALINSPIRAL_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LALINSPIRAL_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
#define LALINSPIRAL_VCS_CLEAN "CLEAN"
#define LALINSPIRAL_VCS_STATUS "CLEAN: All modifications committed"

/* VCS header/library mismatch link check function */
#define LALINSPIRAL_VCS_LINK_CHECK LALINSPIRAL_CLEAN_a00b854511244fc757da2d6f5a689699236e1327_VCS_HEADER_LIBRARY_MISMATCH
void LALINSPIRAL_VCS_LINK_CHECK(void);

#ifdef __cplusplus
}
#endif

#endif /* _LALINSPIRALVCSINFOHEADER_H */

/** \endcond */
